/*
	*
	* Copyright 2019-2021 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project ( https://gitlab.com/desq/ )
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* at your option, any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#include "PowerManager.hpp"
#include "PowerManagerTray.hpp"

PowerTrayIcon::PowerTrayIcon( DesQPowerManager *pm ) : QSystemTrayIcon() {

	mPM = pm;

	setIcon( QIcon( ":/icons/desq-power-manager.png" ) );
	connect( this, SIGNAL( activated( QSystemTrayIcon::ActivationReason ) ), this, SLOT( handleActivation( QSystemTrayIcon::ActivationReason ) ) );

	QMenu *menu = new QMenu( "TrayMenu" );
	menu->setAttribute( Qt::WA_DeleteOnClose );

	menu->addAction( QIcon( ":/icons/desq-power-manager.png" ), "Show PowerManager", this, SLOT( toggleVisible() ) );
	menu->addAction( QIcon::fromTheme( "application-exit" ), "&Quit PowerManager", this, SLOT( quit() ) );
	setContextMenu( menu );

	showInfo();
};

void PowerTrayIcon::handleActivation( QSystemTrayIcon::ActivationReason reason ) {

	switch( reason ) {
		case QSystemTrayIcon::DoubleClick:
		case QSystemTrayIcon::Context: {
			break;
		};

		case QSystemTrayIcon::MiddleClick: {
			qApp->quit();
			break;
		};

		case QSystemTrayIcon::Trigger: {
			toggleVisible();
			break;
		};

		default:{
			break;
		};
	};
};

void PowerTrayIcon::toggleVisible() {

	if ( not mPM )
		return;

	if ( mPM->isVisible() )
		mPM->hide();

	else
		mPM->show();
};

void PowerTrayIcon::showInfo() {

	showMessage(
		"TrayIcon initialized",
		"DesQ PowerManager is now open in SystemTray. Click on the icon to show the PowerManager window, middle-click to quit.",
		QSystemTrayIcon::Information,
		2500
	);
};

void PowerTrayIcon::quit() {

	/* Close all top level widgets */
	mPM->close();

	qApp->quit();
};
